@@ -1,19 +1,8 @@
 /*
- * Copyright 2007-2009 by Stefan Böhmann <kde@hilefoks.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2007-2009 Stefan Böhmann <kde@hilefoks.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
@@ -36,7 +25,7 @@ class SettingsDialog : public QDialog
 {
     public:
         SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas);
-        ~SettingsDialog();
+        ~SettingsDialog() override;
 
     private:
         void updateSelection(const QItemSelection &selected, const QItemSelection &deselected);
